==> blancoTmxUtil-0.0.1-src.zip: src/blanco/tmx/util/task/valueobject/BlancoTmxUtilConvertProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.util.task.valueobject;

/**
 * NX [BlancoTmxUtilConvertProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoTmxUtilConvertProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     */
    private String fSourcedir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     */
    private String fTargetdir;

    /**
     * tB[h [isindentxml]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * XMLCfg邩ǂB
     */
    private boolean fIsindentxml = true;

    /**
     * tB[h [encoding]
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     */
    private String fEncoding;

    /**
     * tB[h [adjustlang]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     */
    private boolean fAdjustlang = false;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [isindentxml]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * XMLCfg邩ǂB
     *
     * @param argIsindentxml tB[h[isindentxml]Ɋi[l
     */
    public void setIsindentxml(final boolean argIsindentxml) {
        fIsindentxml = argIsindentxml;
    }

    /**
     * tB[h[isindentxml]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * XMLCfg邩ǂB
     *
     * @return tB[h[isindentxml]Ɋi[Ăl
     */
    public boolean getIsindentxml() {
        return fIsindentxml;
    }

    /**
     * tB[h [encoding]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     *
     * @param argEncoding tB[h[encoding]Ɋi[l
     */
    public void setEncoding(final String argEncoding) {
        fEncoding = argEncoding;
    }

    /**
     * tB[h[encoding]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     *
     * @return tB[h[encoding]Ɋi[Ăl
     */
    public String getEncoding() {
        return fEncoding;
    }

    /**
     * tB[h [adjustlang]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     *
     * @param argAdjustlang tB[h[adjustlang]Ɋi[l
     */
    public void setAdjustlang(final boolean argAdjustlang) {
        fAdjustlang = argAdjustlang;
    }

    /**
     * tB[h[adjustlang]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     *
     * @return tB[h[adjustlang]Ɋi[Ăl
     */
    public boolean getAdjustlang() {
        return fAdjustlang;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.util.task.valueobject.BlancoTmxUtilConvertProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",isindentxml=" + fIsindentxml);
        buf.append(",encoding=" + fEncoding);
        buf.append(",adjustlang=" + fAdjustlang);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoTmxUtil-0.0.2-src.zip: src/blanco/tmx/util/task/valueobject/BlancoTmxUtilConvertProcessInput.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.tmx.util.task.valueobject;

/**
 * NX [BlancoTmxUtilConvertProcess]̓̓o[IuWFNgNXłB
 */
public class BlancoTmxUtilConvertProcessInput {
    /**
     * tB[h [verbose]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     */
    private boolean fVerbose = false;

    /**
     * tB[h [sourcedir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     */
    private String fSourcedir;

    /**
     * tB[h [targetdir]
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     */
    private String fTargetdir;

    /**
     * tB[h [isindentxml]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * XMLCfg邩ǂB
     */
    private boolean fIsindentxml = true;

    /**
     * tB[h [encoding]
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     */
    private String fEncoding;

    /**
     * tB[h [adjustlang]
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     */
    private boolean fAdjustlang = false;

    /**
     * tB[h [sortorder]
     *
     * ڂ̌^ [int]<br>
     * Kl   [0]<br>
     * \[gB1: ensegAidŃ\[gB
     */
    private int fSortorder = 0;

    /**
     * tB[h [verbose]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * verbose[hœ삳邩ǂB
     *
     * @param argVerbose tB[h[verbose]Ɋi[l
     */
    public void setVerbose(final boolean argVerbose) {
        fVerbose = argVerbose;
    }

    /**
     * tB[h[verbose]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * verbose[hœ삳邩ǂB
     *
     * @return tB[h[verbose]Ɋi[Ăl
     */
    public boolean getVerbose() {
        return fVerbose;
    }

    /**
     * tB[h [sourcedir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     *
     * @param argSourcedir tB[h[sourcedir]Ɋi[l
     */
    public void setSourcedir(final String argSourcedir) {
        fSourcedir = argSourcedir;
    }

    /**
     * tB[h[sourcedir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[Ă͐惋[gEtH_w肵܂B
     *
     * @return tB[h[sourcedir]Ɋi[Ăl
     */
    public String getSourcedir() {
        return fSourcedir;
    }

    /**
     * tB[h [targetdir]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     *
     * @param argTargetdir tB[h[targetdir]Ɋi[l
     */
    public void setTargetdir(final String argTargetdir) {
        fTargetdir = argTargetdir;
    }

    /**
     * tB[h[targetdir]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * TMXt@Ci[o͐惋[gEtH_w肵܂B
     *
     * @return tB[h[targetdir]Ɋi[Ăl
     */
    public String getTargetdir() {
        return fTargetdir;
    }

    /**
     * tB[h [isindentxml]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * XMLCfg邩ǂB
     *
     * @param argIsindentxml tB[h[isindentxml]Ɋi[l
     */
    public void setIsindentxml(final boolean argIsindentxml) {
        fIsindentxml = argIsindentxml;
    }

    /**
     * tB[h[isindentxml]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [true]<br>
     * XMLCfg邩ǂB
     *
     * @return tB[h[isindentxml]Ɋi[Ăl
     */
    public boolean getIsindentxml() {
        return fIsindentxml;
    }

    /**
     * tB[h [encoding]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     *
     * @param argEncoding tB[h[encoding]Ɋi[l
     */
    public void setEncoding(final String argEncoding) {
        fEncoding = argEncoding;
    }

    /**
     * tB[h[encoding]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * XMLGR[fBOB
     *
     * @return tB[h[encoding]Ɋi[Ăl
     */
    public String getEncoding() {
        return fEncoding;
    }

    /**
     * tB[h [adjustlang]̃Zb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     *
     * @param argAdjustlang tB[h[adjustlang]Ɋi[l
     */
    public void setAdjustlang(final boolean argAdjustlang) {
        fAdjustlang = argAdjustlang;
    }

    /**
     * tB[h[adjustlang]̃Qb^[\bh
     *
     * ڂ̌^ [boolean]<br>
     * Kl   [false]<br>
     * lang 𒲐邩ǂ? |uCł悤ɉHɂ͂ true ɃZbgB
     *
     * @return tB[h[adjustlang]Ɋi[Ăl
     */
    public boolean getAdjustlang() {
        return fAdjustlang;
    }

    /**
     * tB[h [sortorder]̃Zb^[\bh
     *
     * ڂ̌^ [int]<br>
     * \[gB1: ensegAidŃ\[gB
     *
     * @param argSortorder tB[h[sortorder]Ɋi[l
     */
    public void setSortorder(final int argSortorder) {
        fSortorder = argSortorder;
    }

    /**
     * tB[h[sortorder]̃Qb^[\bh
     *
     * ڂ̌^ [int]<br>
     * Kl   [0]<br>
     * \[gB1: ensegAidŃ\[gB
     *
     * @return tB[h[sortorder]Ɋi[Ăl
     */
    public int getSortorder() {
        return fSortorder;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.tmx.util.task.valueobject.BlancoTmxUtilConvertProcessInput[");
        buf.append("verbose=" + fVerbose);
        buf.append(",sourcedir=" + fSourcedir);
        buf.append(",targetdir=" + fTargetdir);
        buf.append(",isindentxml=" + fIsindentxml);
        buf.append(",encoding=" + fEncoding);
        buf.append(",adjustlang=" + fAdjustlang);
        buf.append(",sortorder=" + fSortorder);
        buf.append("]");
        return buf.toString();
    }
}
